==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_workflow/TransferWorkflowOnExceptionStepsOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.transfer_workflow;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.971Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferWorkflow.TransferWorkflowOnExceptionStepsOutputReference")
public class TransferWorkflowOnExceptionStepsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected TransferWorkflowOnExceptionStepsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TransferWorkflowOnExceptionStepsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TransferWorkflowOnExceptionStepsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCopyStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putCopyStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCustomStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putCustomStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDeleteStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putDeleteStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putTagStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putTagStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCopyStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetCopyStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCustomStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetCustomStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetTagStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetTagStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetailsOutputReference getCopyStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "copyStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetailsOutputReference getCustomStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "customStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetailsOutputReference getDeleteStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "deleteStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetailsOutputReference getTagStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "tagStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails getCopyStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "copyStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails getCustomStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "customStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails getDeleteStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails getTagStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "tagStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getTypeInput() {
        return software.amazon.jsii.Kernel.get(this, "typeInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getType() {
        return software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setType(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "type", java.util.Objects.requireNonNull(value, "type is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionSteps value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_workflow/TransferWorkflowOnExceptionStepsOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.transfer_workflow;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.029Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferWorkflow.TransferWorkflowOnExceptionStepsOutputReference")
public class TransferWorkflowOnExceptionStepsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected TransferWorkflowOnExceptionStepsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TransferWorkflowOnExceptionStepsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TransferWorkflowOnExceptionStepsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCopyStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putCopyStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putCustomStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putCustomStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDecryptStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDecryptStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putDecryptStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putDeleteStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putDeleteStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putTagStepDetails(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails value) {
        software.amazon.jsii.Kernel.call(this, "putTagStepDetails", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCopyStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetCopyStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetCustomStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetCustomStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDecryptStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetDecryptStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetDeleteStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetDeleteStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetTagStepDetails() {
        software.amazon.jsii.Kernel.call(this, "resetTagStepDetails", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetailsOutputReference getCopyStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "copyStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetailsOutputReference getCustomStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "customStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDecryptStepDetailsOutputReference getDecryptStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "decryptStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDecryptStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetailsOutputReference getDeleteStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "deleteStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetailsOutputReference getTagStepDetails() {
        return software.amazon.jsii.Kernel.get(this, "tagStepDetails", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetailsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails getCopyStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "copyStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCopyStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails getCustomStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "customStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsCustomStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDecryptStepDetails getDecryptStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "decryptStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDecryptStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails getDeleteStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "deleteStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsDeleteStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails getTagStepDetailsInput() {
        return software.amazon.jsii.Kernel.get(this, "tagStepDetailsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionStepsTagStepDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.String getTypeInput() {
        return software.amazon.jsii.Kernel.get(this, "typeInput", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getType() {
        return software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setType(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.set(this, "type", java.util.Objects.requireNonNull(value, "type is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.IResolvable value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_workflow.TransferWorkflowOnExceptionSteps value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
